cv.views — Django-CV 0.0.1 documentation

# `cv.views`

Reference for `cv.views` generated from docstrings.

`cv.views.` `sum_items`(dict)

  Sum items across dictionaries.

`cv.views.` `get_cv_primary_positions`()

  Return dictionary of CV data with current positions.

`cv.views.` `get_cv_personnel_data`()

  Return dictionary of CV data related to personnel and awards.

`cv.views.` `get_cv_service_data`()

  Return dictionary of services at different levels.

`cv.views.` `get_cv_journal_service_data`()

  Return dictionary of journals served.

`cv.views.` `get_cv_article_data`()

  Return dictionary of articles in different stages of publication.

`cv.views.` `get_cv_chapter_data`()

  Return dictionary of chapters in different stages of publication.

`cv.views.` `get_cv_book_data`()

  Return dictionary of books in different stages of publication.

`cv.views.` `get_cv_grant_data`()

  Return dictionary of grants.

`cv.views.` `get_cv_report_data`()

  Return dictionary of reports in different stages of publication.

`cv.views.` `get_cv_otherwriting_data`()

  Return dictionary of other writing objects.

`cv.views.` `get_cv_talk_data`()

  Return dictionary of talks.

`cv.views.` `get_cv_media_data`()

  Return dictionary of media mentions.

`cv.views.` `get_cv_teaching_data`()

  Return dictionary of teaching and mentoring.

`cv.views.` `get_cv_data`()

  Return dictionary of different types of CV entries.

`cv.views.` `cv_list`(request)

  Create view of entire CV for printing in html.

class `cv.views.` `ArticleListView`(**kwargs)

  Return list of articles

  `get_queryset`()

    Return the list of items for this view.

    The return value must be an iterable and may be an instance of QuerySet in which case QuerySet specific behavior will be enabled.

class `cv.views.` `ArticleDetailView`(**kwargs)

  Return view of a single article

  `model`

    alias of `cv.models.publications.Article`

`cv.views.` `article_citation_view`(request, slug, format)

  Returns view to allow citation to be downloaded to citation management software.

class `cv.views.` `BookListView`(**kwargs)

  Return list of books

  `get_queryset`()

    Return the list of items for this view.

    The return value must be an iterable and may be an instance of QuerySet in which case QuerySet specific behavior will be enabled.

class `cv.views.` `BookDetailView`(**kwargs)

  Return view of single book

  `model`

    alias of `cv.models.publications.Book`

`cv.views.` `book_citation_view`(request, slug, format)

  Returns view to allow citation to be downloaded to citation management software in RIS or BibTeX formats.

class `cv.views.` `ChapterListView`(**kwargs)

  Return view containing list of chapters.

  `get_queryset`()

    Return the list of items for this view.

    The return value must be an iterable and may be an instance of QuerySet in which case QuerySet specific behavior will be enabled.

class `cv.views.` `ChapterDetailView`(**kwargs)

  Return view containing details of single chapter.

  `model`

    alias of `cv.models.publications.Chapter`

`cv.views.` `chapter_citation_view`(request, slug, format)

  Returns citation to be downloaded to citation management software.

class `cv.views.` `ReportListView`(**kwargs)

  Return view containing list of reports.

  `get_queryset`()

    Return the list of items for this view.

    The return value must be an iterable and may be an instance of QuerySet in which case QuerySet specific behavior will be enabled.

class `cv.views.` `ReportDetailView`(**kwargs)

  Return view containing details of single report.

  `model`

    alias of `cv.models.publications.Report`

`cv.views.` `report_citation_view`(request, slug, format)

  Returns view to allow citation to be downloaded to citation management software.

class `cv.views.` `TalkListView`(**kwargs)

  Return list of articles.

  `model`

    alias of `cv.models.works.Talk`

class `cv.views.` `TalkDetailView`(**kwargs)

  Return view of a single talk.

  `model`

    alias of `cv.models.works.Talk`

`cv.views.` `talk_citation_view`(request, slug, format)

  Returns view to allow citation to be downloaded to citation management software.

class `cv.views.` `GrantListView`(**kwargs)

  Return list of grants.

  `model`

    alias of `cv.models.works.Grant`

class `cv.views.` `GrantDetailView`(**kwargs)

  Return view of a single grant.

  `model`

    alias of `cv.models.works.Grant`

class `cv.views.` `CVListView`(**kwargs)

  Returns view of all instances for a particular object.

  `dispatch`(request, *args, **kwargs)

    Set class parameters based on URL and dispatch.

  `get_template_names`()

    Returns the name template to use to display a list of model instances.

    Currently returns `cv/lists/<model_name>_list.html`.

    Might add a generic template for vitae models in the future.

class `cv.views.` `CVDetailView`(**kwargs)
  `get_template_names`()

    Return a list of template names to be used for the request. May not be called if render_to_response() is overridden. Return the following list:

    - the value of `template_name` on the view (if provided)
    - the contents of the `template_name_field` field on the object instance that the view is operating upon (if available)
    - `<app_label>/<model_name><template_name_suffix>.html`

class `cv.views.` `CVSingleObjectMixin`

  Provide basic methods for manipulating CV views.

  `dispatch`(request, *args, **kwargs)

    Set class parameters and dispatch to right method.

  `get_context_data`(**kwargs)

    Set common context variables for CV views and set value of authorship formset

    `self.formset` will be: * `inlineformset_factory` for the authorship model if one exists * `None` otherwise

  `get_template_names`()

    Return a list of template names to be used for the form to create a new object. Returns either: * `cv/forms/<model_name>_add_form.html` or * the `template_name` defined for the view

class `cv.views.` `CVCreateView`(**kwargs)

  View to create CV objects

  `get_context_data`(**kwargs)

    Insert authorship formset into the context dict.

  `form_valid`(form)

    Save authorship formset data if valid.

class `cv.views.` `CVUpdateView`(**kwargs)

  View to edit CV objects.

  `get_context_data`(**kwargs)

    Insert the form into the context dict.

class `cv.views.` `CVDeleteView`(**kwargs)